------------------------------------------------------------------------------------
-- OU4 routine data with all dimensions (categorycombinations, DE and OU groupsets)
--DROP VIEW pivotsource_routinedata_ou4_all;

CREATE OR REPLACE VIEW pivotsource_routinedata_ou4_all AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 
organisationunit_4.name AS orgunit4, 
organisationunit_4.shortname AS ou4,
dataelement.name AS dataelement, 
dataelement.shortname AS deshort,
categoryoptioncomboname.categoryoptioncomboname as catoptioncombo, 

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char

(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

aggregateddatavalue.value, 
aggregateddatavalue.level,

--- additional dimension based on catcombos/category
--- additional dimension based on data element (all) and orgunit groupsets (selected)
_categorystructure.*,
_dataelementgroupsetstructure.*,
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
dataelement dataelement, _categorystructure, _dataelementgroupsetstructure,categoryoptioncomboname,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, organisationunit organisationunit_4, _organisationunitgroupsetstructure,
aggregateddatavalue aggregateddatavalue

WHERE 	
dataelement.dataelementid = aggregateddatavalue.dataelementid AND 
_categorystructure.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND 
_dataelementgroupsetstructure.dataelementid = aggregateddatavalue.dataelementid AND
categoryoptioncomboname.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND

period.periodid = aggregateddatavalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 
periodtype.name::text = 'Monthly'::text AND 

orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
orgunitstructure.idlevel4 = organisationunit_4.organisationunitid AND
_organisationunitgroupsetstructure.organisationunitid = aggregateddatavalue.organisationunitid  AND

aggregateddatavalue.level = 4

ORDER BY period.startdate;

ALTER TABLE pivotsource_routinedata_ou4_all OWNER TO dhis;

-----------------------------------------------------------------------------
--DROP VIEW pivotsource_routinedata_ou3_all;

-- OU3 routine data with all dimensions (categorycombinations, DE and OU groupsets)
--- (Note that OU4 level gives more detail on the OU groupset Type as all groups above lowest level are usually the same type (chiefdom, district etc.)

CREATE OR REPLACE VIEW pivotsource_routinedata_ou3_all AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 
dataelement.name AS dataelement, 
dataelement.shortname AS deshort, 
categoryoptioncomboname.categoryoptioncomboname as catoptioncombo,

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char

(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

aggregateddatavalue.value, aggregateddatavalue.level,

--- additional dimension based on catcombos/category
--- additional dimension based on data element (all) and orgunit groupsets (selected)

_categorystructure.*,
_dataelementgroupsetstructure.*,
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
dataelement dataelement, _categorystructure, _dataelementgroupsetstructure,categoryoptioncomboname,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, _organisationunitgroupsetstructure,
aggregateddatavalue aggregateddatavalue

WHERE 	
dataelement.dataelementid = aggregateddatavalue.dataelementid AND 
_categorystructure.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND 
_dataelementgroupsetstructure.dataelementid = aggregateddatavalue.dataelementid AND
categoryoptioncomboname.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND

period.periodid = aggregateddatavalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 
periodtype.name::text = 'Monthly'::text AND 

orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
_organisationunitgroupsetstructure.organisationunitid = aggregateddatavalue.organisationunitid  AND

aggregateddatavalue.level = 3

ORDER BY period.startdate;

ALTER TABLE pivotsource_routinedata_ou3_all OWNER TO dhis;

-----------------------------------------------------------------------------
-- DROP VIEW pivotsource_routinedata_ou4;


-- standard view for OU4 data

CREATE OR REPLACE VIEW pivotsource_routinedata_ou4 AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 
organisationunit_4.name AS orgunit4, 
organisationunit_4.shortname AS ou4,
dataelement.name AS dataelement, 
dataelement.shortname AS deshort, 
categoryoptioncomboname.categoryoptioncomboname as catoptioncombo,

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char

(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

aggregateddatavalue.value, aggregateddatavalue.level,

--- additional dimension based on data element and orgunit groupsets
--- catcombos/category dimensions are not included in the standard view

_dataelementgroupsetstructure.*,
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
dataelement dataelement, _dataelementgroupsetstructure, categoryoptioncomboname,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, organisationunit organisationunit_4, _organisationunitgroupsetstructure,
aggregateddatavalue aggregateddatavalue

WHERE 	
dataelement.dataelementid = aggregateddatavalue.dataelementid AND 
_dataelementgroupsetstructure.dataelementid = aggregateddatavalue.dataelementid AND
categoryoptioncomboname.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND

period.periodid = aggregateddatavalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 

-- replace 'Monthly' with e.g. 'Weekly','Quarterly'. or 'Yearly' if needed
-- mixing period typesin the same pivot table or cube messes up the automatic aggregation in Exel and you will most likelt get duplicates

periodtype.name::text = 'Monthly'::text AND 

orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
orgunitstructure.idlevel4 = organisationunit_4.organisationunitid AND
_organisationunitgroupsetstructure.organisationunitid = aggregateddatavalue.organisationunitid  AND

aggregateddatavalue.level = 4

ORDER BY period.startdate;

ALTER TABLE pivotsource_routinedata_ou4 OWNER TO dhis;

-----------------------------------------------------------------------------
-- DROP VIEW pivotsource_routinedata_ou3;

-- standard view for OU3 data

CREATE OR REPLACE VIEW pivotsource_routinedata_ou3 AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 
dataelement.name AS dataelement, 
dataelement.shortname AS deshort,
categoryoptioncomboname.categoryoptioncomboname as catoptioncombo, 

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char

(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

aggregateddatavalue.value, aggregateddatavalue.level,

--- additional dimension based on data element
--- catcombos/category dimensions are not included in the standard view

_dataelementgroupsetstructure.*,
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
dataelement dataelement, _dataelementgroupsetstructure,categoryoptioncomboname,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, _organisationunitgroupsetstructure,
aggregateddatavalue aggregateddatavalue

WHERE 	
dataelement.dataelementid = aggregateddatavalue.dataelementid AND 
_dataelementgroupsetstructure.dataelementid = aggregateddatavalue.dataelementid AND
categoryoptioncomboname.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND

period.periodid = aggregateddatavalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 

-- replace 'Monthly' with e.g. 'Weekly','Quarterly'. or 'Yearly' if needed
-- mixing period types in the same pivot table or cube messes up the automatic aggregation in Exel and you will most likelt get duplicates
periodtype.name::text = 'Monthly'::text AND 

orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
_organisationunitgroupsetstructure.organisationunitid = aggregateddatavalue.organisationunitid  AND

aggregateddatavalue.level = 3

ORDER BY period.startdate;

ALTER TABLE pivotsource_routinedata_ou3 OWNER TO dhis;

-----------------------------------------------------------------------------
--DROP VIEW pivotsource_routinedata_ou2;

-- standard view for OU2 data

CREATE OR REPLACE VIEW pivotsource_routinedata_ou2 AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
dataelement.name AS dataelement, 
dataelement.shortname AS deshort,
categoryoptioncomboname.categoryoptioncomboname as catoptioncombo,

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char

(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

aggregateddatavalue.value, aggregateddatavalue.level,

--- additional dimension based on data element
--- catcombos/category dimensions are not included in the standard view

_dataelementgroupsetstructure.*,
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
dataelement dataelement, _dataelementgroupsetstructure,categoryoptioncomboname,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, _organisationunitgroupsetstructure,
aggregateddatavalue aggregateddatavalue

WHERE 	
dataelement.dataelementid = aggregateddatavalue.dataelementid AND 
_dataelementgroupsetstructure.dataelementid = aggregateddatavalue.dataelementid AND
categoryoptioncomboname.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND

period.periodid = aggregateddatavalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 

-- replace 'Monthly' with e.g. 'Weekly','Quarterly'. or 'Yearly' if needed
-- mixing perid types in the same pivot table or cube messes up the automatic aggregation in Exel and you will most likelt get duplicates
periodtype.name::text = 'Monthly'::text AND 

orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
_organisationunitgroupsetstructure.organisationunitid = aggregateddatavalue.organisationunitid  AND

aggregateddatavalue.level = 2

ORDER BY period.startdate;

ALTER TABLE pivotsource_routinedata_ou2 OWNER TO dhis;

----------------------------------------------------------

---- INDICATOR VIEWS --------------

---------------------------------

-----------------------------------------------------------------------------

-- standard view for OU4 indicator data

--DROP VIEW pivotsource_indicator_ou4;

CREATE OR REPLACE VIEW pivotsource_indicator_ou4 AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 
organisationunit_4.name AS orgunit4, 
organisationunit_4.shortname AS ou4,
indicator.name AS indicator, 
indicator.shortname AS indshort, 

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char

(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

----- to properly aggregate indicator values (the percentages) up the orgunit hierarchy in pivot tables or cube based tools, 
----- you should define a new calculated field as the formula of 'numxfactor/denominatorvalue' in your analysis tool (or cube definition)

(aggregatedindicatorvalue.factor * aggregatedindicatorvalue.numeratorvalue) AS numxfactor, 
aggregatedindicatorvalue.denominatorvalue, 
aggregatedindicatorvalue.numeratorvalue,
aggregatedindicatorvalue.annualized, 


aggregatedindicatorvalue.level,

--- additional dimension based on data element and orgunit groupsets
--- catcombos/category dimensions are not included in the standard view

_indicatorgroupsetstructure.*,
--- NOTE: Type and Ownership are two standard orgunit groupsets. Replace/add column names here if using other names or other groupsets
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
indicator indicator, _indicatorgroupsetstructure,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, organisationunit organisationunit_4, _organisationunitgroupsetstructure,
aggregatedindicatorvalue aggregatedindicatorvalue

WHERE 	
indicator.indicatorid = aggregatedindicatorvalue.indicatorid AND 
_indicatorgroupsetstructure.indicatorid = aggregatedindicatorvalue.indicatorid AND

period.periodid = aggregatedindicatorvalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 

-- replace 'Monthly' with e.g. 'Weekly','Quarterly'. or 'Yearly' if needed
-- mixing period types in the same pivot table or cube messes up the automatic aggregation in Exel and you will most likelt get duplicates

periodtype.name::text = 'Monthly'::text AND 

orgunitstructure.organisationunitid = aggregatedindicatorvalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
orgunitstructure.idlevel4 = organisationunit_4.organisationunitid AND
_organisationunitgroupsetstructure.organisationunitid = aggregatedindicatorvalue.organisationunitid  AND

aggregatedindicatorvalue.level = 4

ORDER BY period.startdate;

ALTER TABLE pivotsource_indicator_ou4 OWNER TO dhis;

----------------------------------------------------------

-- standard view for OU3 indicator data

--DROP VIEW pivotsource_indicator_ou3;

CREATE OR REPLACE VIEW pivotsource_indicator_ou3 AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 

indicator.name AS indicator, 
indicator.shortname AS indshort, 

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char

(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

----- to properly aggregate indicator values (the percentages) up the orgunit hierarchy in pivot tables or cube based tools, 
----- you should define a new calculated field as the formula of 'numxfactor/denominatorvalue' in your analysis tool (or cube definition)

(aggregatedindicatorvalue.factor * aggregatedindicatorvalue.numeratorvalue) AS numxfactor, 
aggregatedindicatorvalue.denominatorvalue, 
aggregatedindicatorvalue.numeratorvalue,
aggregatedindicatorvalue.annualized, 


aggregatedindicatorvalue.level,

--- additional dimension based on data element and orgunit groupsets
--- catcombos/category dimensions are not included in the standard view

_indicatorgroupsetstructure.*,
--- NOTE: Type and Ownership are two standard orgunit groupsets. Replace/add column names here if using other names or other groupsets
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
indicator indicator, _indicatorgroupsetstructure,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, _organisationunitgroupsetstructure,
aggregatedindicatorvalue aggregatedindicatorvalue

WHERE 	
indicator.indicatorid = aggregatedindicatorvalue.indicatorid AND 
_indicatorgroupsetstructure.indicatorid = aggregatedindicatorvalue.indicatorid AND

period.periodid = aggregatedindicatorvalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 

-- replace 'Monthly' with e.g. 'Weekly','Quarterly'. or 'Yearly' if needed
-- mixing period types in the same pivot table or cube messes up the automatic aggregation in Exel and you will most likelt get duplicates

periodtype.name::text = 'Monthly'::text AND 

orgunitstructure.organisationunitid = aggregatedindicatorvalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
_organisationunitgroupsetstructure.organisationunitid = aggregatedindicatorvalue.organisationunitid  AND

aggregatedindicatorvalue.level = 3

ORDER BY period.startdate;

ALTER TABLE pivotsource_indicator_ou3 OWNER TO dhis;

----------------------------------------------------------
--- view to fecth routine data for OU4 level with only totals for data elements (no catoptioncombos)
CREATE VIEW pivotsource_routinedataOU4_totals AS
SELECT 

organisationunit_2.name AS orgunit2, 
organisationunit_3.name AS orgunit3, 
organisationunit_4.name AS orgunit4, 

"dataelement"."name", 
periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
to_char(period.startdate::timestamp with time zone, 'Mon'::text) AS month, 
SUM("aggregateddatavalue"."value") 


FROM 
"public"."dataelement" AS "dataelement", "public"."aggregateddatavalue" AS "aggregateddatavalue", "public"."period" AS "period", periodtype, 
organisationunit organisationunit_2, organisationunit organisationunit_3, organisationunit organisationunit_4,orgunitstructure

WHERE "dataelement"."dataelementid" = "aggregateddatavalue"."dataelementid" AND "period"."periodid" = "aggregateddatavalue"."periodid" AND 
orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
orgunitstructure.idlevel4 = organisationunit_4.organisationunitid AND
aggregateddatavalue.level = 4 AND
period.periodtypeid=periodtype.periodtypeid AND
periodtype.name::text = 'Monthly'::text

GROUP BY
orgunit2, 
orgunit3, 
orgunit4, 
"dataelement"."name", 
periodtype, 
year, 
month;
---------------------------------
-- DROP VIEW pivotsource_routinedata_ou4_yearly;


-- standard view for OU4 data

CREATE OR REPLACE VIEW pivotsource_routinedata_ou4_yearly AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 
organisationunit_4.name AS orgunit4, 
organisationunit_4.shortname AS ou4,
dataelement.name AS dataelement, 
dataelement.shortname AS deshort, 
categoryoptioncomboname.categoryoptioncomboname as catoptioncombo,

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

aggregateddatavalue.value, aggregateddatavalue.level,

--- additional dimension based on data element and orgunit groupsets
--- catcombos/category dimensions are not included in the standard view

_dataelementgroupsetstructure.*,
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
dataelement dataelement, _dataelementgroupsetstructure, categoryoptioncomboname,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, organisationunit organisationunit_4, _organisationunitgroupsetstructure,
aggregateddatavalue aggregateddatavalue

WHERE 	
dataelement.dataelementid = aggregateddatavalue.dataelementid AND 
_dataelementgroupsetstructure.dataelementid = aggregateddatavalue.dataelementid AND
categoryoptioncomboname.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND

period.periodid = aggregateddatavalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 

-- replace 'Monthly' with e.g. 'Weekly','Quarterly'. or 'Yearly' if needed
-- mixing period typesin the same pivot table or cube messes up the automatic aggregation in Exel and you will most likelt get duplicates

periodtype.name::text = 'Yearly'::text AND 

orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
orgunitstructure.idlevel4 = organisationunit_4.organisationunitid AND
_organisationunitgroupsetstructure.organisationunitid = aggregateddatavalue.organisationunitid  AND

aggregateddatavalue.level = 4

ORDER BY period.startdate;

ALTER TABLE pivotsource_routinedata_ou4_yearly OWNER TO dhis;
--------------------------------------------------------------
-- DROP VIEW pivotsource_routinedata_ou3_yearly;


-- standard view for OU3 data

CREATE OR REPLACE VIEW pivotsource_routinedata_ou3_yearly AS 
 SELECT 
organisationunit_1.name AS orgunit1, 
organisationunit_1.shortname AS ou1, 
organisationunit_2.name AS orgunit2, 
organisationunit_2.shortname AS ou2, 
organisationunit_3.name AS orgunit3, 
organisationunit_3.shortname AS ou3, 
dataelement.name AS dataelement, 
dataelement.shortname AS deshort, 
categoryoptioncomboname.categoryoptioncomboname as catoptioncombo,

periodtype.name AS periodtype, 
to_char(period.startdate::timestamp with time zone, 'YYYY'::text) AS year, 
(rtrim(to_char(period.startdate::timestamp with time zone, 'Mon'::text)) || '-'::text) || to_char(period.startdate::timestamp with time zone, 'YY'::text) AS period, 

aggregateddatavalue.value, aggregateddatavalue.level,

--- additional dimension based on data element and orgunit groupsets
--- catcombos/category dimensions are not included in the standard view

_dataelementgroupsetstructure.*,
_organisationunitgroupsetstructure.type as ou_type,
_organisationunitgroupsetstructure.ownership as ou_ownership,
_organisationunitgroupsetstructure.local_council as ou_local_council

FROM 
dataelement dataelement, _dataelementgroupsetstructure, categoryoptioncomboname,
period period, periodtype periodtype, 
orgunitstructure orgunitstructure, organisationunit organisationunit_1, organisationunit organisationunit_2, organisationunit organisationunit_3, _organisationunitgroupsetstructure,
aggregateddatavalue aggregateddatavalue

WHERE 	
dataelement.dataelementid = aggregateddatavalue.dataelementid AND 
_dataelementgroupsetstructure.dataelementid = aggregateddatavalue.dataelementid AND
categoryoptioncomboname.categoryoptioncomboid = aggregateddatavalue.categoryoptioncomboid AND

period.periodid = aggregateddatavalue.periodid AND 
period.periodtypeid = periodtype.periodtypeid AND 

-- replace 'Monthly' with e.g. 'Weekly','Quarterly'. or 'Yearly' if needed
-- mixing period typesin the same pivot table or cube messes up the automatic aggregation in Exel and you will most likelt get duplicates

periodtype.name::text = 'Yearly'::text AND 

orgunitstructure.organisationunitid = aggregateddatavalue.organisationunitid AND 
orgunitstructure.idlevel1 = organisationunit_1.organisationunitid AND 
orgunitstructure.idlevel2 = organisationunit_2.organisationunitid AND 
orgunitstructure.idlevel3 = organisationunit_3.organisationunitid AND 
_organisationunitgroupsetstructure.organisationunitid = aggregateddatavalue.organisationunitid  AND

aggregateddatavalue.level = 3

ORDER BY period.startdate;

ALTER TABLE pivotsource_routinedata_ou3_yearly OWNER TO dhis;

